jQuery(document).ready(function($) {
    const id = 'zetdl-block';

    const deleteToDo = (id, elem) => {
        $.ajax({
            url: `${config.ajax_url}?action=zetdl_delete_to_do&id=${id}&nonce=${config.nonce}`,
            type: 'DELETE',
            success: function(response) {
                $(elem).css('animation', 'fadeOut 0.5s ease forwards');
                $(elem).on('animationend', function() {
                    $(this).remove();
                });
            },
        });
    }

    const registerDeleteEvent = (itemId) => {
        const deleteAction = function() {
            if (!confirm(`Confirm delete this item from your to do list?`)) {
                return;
            }
            deleteToDo($(this).attr('data-id'), $(this).parent());
        };
        
        $(`#${id} .to-do-delete[data-id="${itemId}"]`).click(deleteAction);
    };

    const retrieveToDos = () => {
        $.ajax({
            url: config.ajax_url,
            type: 'GET',
            data: {
                action: 'zetdl_retrieve_to_dos',
                nonce: config.nonce,
            },
            success: function(response) {
                const items = response.data || [];
                for (const item of items) {
                    const html = `<li><span>${item.name}</span><button class="to-do-delete" data-id="${item.id}">X</button></li>`;
                    $(`#${id} .to-do-list`).append(html);
                    registerDeleteEvent(item.id);
                }
            },
        });
    };

    const retrieveToDo = (itemId) => {
        $.ajax({
            url: config.ajax_url,
            type: 'GET',
            data: {
                action: 'zetdl_retrieve_to_do',
                nonce: config.nonce,
                id: itemId,
            },
            success: function(response) {
                const item = response.data || {};
                const html = `<li><span>${item.name}</span><button class="to-do-delete" data-id="${item.id}">X</button></li>`
                $(`#${id} .to-do-list`).append(html);
                registerDeleteEvent(itemId);
            },
        });
    };

    $(`#${id} .to-do-add`).click(function() {
        const name = $(`#${id} .to-do-name`).val();
        if (!(name && name.length > 0)) {
            return;
        }

        $.ajax({
            url: config.ajax_url,
            type: 'POST',
            data: {
                action: 'zetdl_add_to_do',
                nonce: config.nonce,
                name,
            },
            success: function(response) {
                retrieveToDo(response.data.id);
                $(`#${id} .to-do-name`).val('');
            },
        });
    });

    retrieveToDos();
});