<?php
/**
 * Plugin Name:       ZE To Do List
 * Description:       Allow logged in users to create to do list.
 * Requires at least: 6.6
 * Requires PHP:      7.2
 * Version:           0.1.0
 * Author:            Wan Zhen En
 * License:           GPL-2.0-or-later
 * License URI:       https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain:       ze-to-do-list
 *
 * @package CreateBlock
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Registers the block using the metadata loaded from the `block.json` file.
 * Behind the scenes, it registers also all assets so they can be enqueued
 * through the block editor in the corresponding context.
 *
 * @see https://developer.wordpress.org/reference/functions/register_block_type/
 */
function zetdl_create_block_to_do_list_block_block_init() {
	register_block_type( __DIR__ . '/build' );
}
add_action( 'init', 'zetdl_create_block_to_do_list_block_block_init' );

register_activation_hook( __FILE__, 'zetdl_create_to_do_list_table' );
function zetdl_create_to_do_list_table() {
    global $wpdb;

    $table_name = $wpdb->prefix . 'zetdl_to_dos';

    $charset_collate = $wpdb->get_charset_collate();

    $sql = "CREATE TABLE $table_name (
        id mediumint(9) NOT NULL AUTO_INCREMENT,
		user_id bigint(20) NOT NULL,
        name varchar(255) NOT NULL,
        sort_order int unsigned DEFAULT 0,
        created_at datetime DEFAULT CURRENT_TIMESTAMP NOT NULL,
        PRIMARY KEY  (id)
    ) $charset_collate;";

    require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
    
    dbDelta( $sql );
}

function zetdl_to_do_list_enqueue_styles() {
    wp_enqueue_style('zetdl-style', plugin_dir_url( __FILE__ ) . '/style.css', array(), '0.1.0', 'all');
}
add_action( 'wp_enqueue_scripts', 'zetdl_to_do_list_enqueue_styles' );

function zetdl_to_do_list_enqueue_scripts() {
    $nonce = wp_create_nonce('zetdl_nonce');

    wp_enqueue_script('jquery');
    wp_enqueue_script( 'zetdl-script', plugin_dir_url( __FILE__ ) . '/script.js', array( 'jquery' ), '0.1.0', true);
	wp_localize_script('zetdl-script', 'config', array(
		'ajax_url' => admin_url('admin-ajax.php'),
        'nonce' => $nonce,
	));
}
add_action( 'wp_enqueue_scripts', 'zetdl_to_do_list_enqueue_scripts' );

function zetdl_retrieve_to_dos() {
    check_ajax_referer('zetdl_nonce', 'nonce');

	global $wpdb;
    $table_name = $wpdb->prefix . 'zetdl_to_dos';
    
    $query = $wpdb->prepare("SELECT * FROM $table_name WHERE user_id = %d", get_current_user_id());
    $results = $wpdb->get_results($query, ARRAY_A);
    
    if (!empty($results)) {
        wp_send_json_success($results);
    } else {
        wp_send_json_error([]);
    }
    
    wp_die();
}
add_action('wp_ajax_zetdl_retrieve_to_dos', 'zetdl_retrieve_to_dos');

function zetdl_retrieve_to_do() {
    check_ajax_referer('zetdl_nonce', 'nonce');

	global $wpdb;
    $table_name = $wpdb->prefix . 'zetdl_to_dos';

    $id = isset($_GET['id']) ? sanitize_text_field(wp_unslash($_GET['id'])) : -1;
    
    $query = $wpdb->prepare("SELECT * FROM $table_name WHERE id = %d AND user_id = %d", $id, get_current_user_id());
    $result = $wpdb->get_row($query, ARRAY_A);
    
    if ($result) {
        wp_send_json_success($result);
    } else {
        wp_send_json_error([]);
    }
    
    wp_die();
}
add_action('wp_ajax_zetdl_retrieve_to_do', 'zetdl_retrieve_to_do');

function zetdl_add_to_do() {
    check_ajax_referer('zetdl_nonce', 'nonce');

	global $wpdb;
	$table_name = $wpdb->prefix . 'zetdl_to_dos';

    $name = isset($_POST['name']) ? sanitize_text_field(wp_unslash($_POST['name'])) : '';
    if (empty($name)) {
        wp_send_json_error('Could not insert data.');
    }

	$data = array(
		'user_id' => get_current_user_id(),
		'name' => $name,
	);

	$inserted = $wpdb->insert($table_name, $data);

    $response = array(
        'id' => $wpdb->insert_id,
    );

    if ($inserted) {
        wp_send_json_success($response);
    } else {
        wp_send_json_error('Could not insert data.');
    }

    wp_die();
}
add_action('wp_ajax_zetdl_add_to_do', 'zetdl_add_to_do');
// add_action('wp_ajax_nopriv_add_to_do', 'zetdl_add_to_do');

function zetdl_delete_to_do() {
    check_ajax_referer('zetdl_nonce', 'nonce');
    
	if (isset($_SERVER['REQUEST_METHOD']) && $_SERVER['REQUEST_METHOD'] !== 'DELETE') {
		wp_send_json_error('Invalid request method.');
		wp_die();
	} 

	global $wpdb;
	$table_name = $wpdb->prefix . 'zetdl_to_dos';

    $id = isset($_GET['id']) ? sanitize_text_field(wp_unslash($_GET['id'])) : -1;

	$data = array(
		'id' => $id,
		'user_id' => get_current_user_id(),
	);

	$deleted = $wpdb->delete($table_name, $data);

    if ($deleted) {
        wp_send_json_success();
    } else {
        wp_send_json_error('Could not insert data.');
    }

    wp_die();
}
add_action('wp_ajax_zetdl_delete_to_do', 'zetdl_delete_to_do');

